#include "useragent/useragent.h"
#include <KPluginFactory>

K_PLUGIN_CLASS_WITH_JSON(UserAgent, "useragent/khtml_useragent.json")

#include "khtml_useragent.moc"

